@@ -40,8 +40,8 @@ class BaremetalClient(base.BaremetalClient):
         for iface in base.SUPPORTED_INTERFACES
     )
 
-    @staticmethod
-    def _get_headers(api_version):
+    @classmethod
+    def _get_headers(cls, api_version):
         """Return headers for a request.
 
         Currently supports a header specifying the API version to use.
@@ -55,7 +55,7 @@ class BaremetalClient(base.BaremetalClient):
         headers = None
         if api_version is not None:
             extra_headers = True
-            headers = {'x-openstack-ironic-api-version': api_version}
+            headers = {cls.api_microversion_header_name: api_version}
         return extra_headers, headers
 
     @base.handle_errors
@@ -839,7 +839,7 @@ class BaremetalClient(base.BaremetalClient):
         headers = None
         if api_version is not None:
             extra_headers = True
-            headers = {'x-openstack-ironic-api-version': api_version}
+            headers = {self.api_microversion_header_name: api_version}
         return self._list_request('nodes/%s/vifs' % node_uuid,
                                   headers=headers,
                                   extra_headers=extra_headers)
@@ -1008,3 +1008,35 @@ class BaremetalClient(base.BaremetalClient):
         }
 
         return self._create_request_no_response_body('heartbeat', kwargs)
+
+    @base.handle_errors
+    def show_inventory(self, uuid, api_version='1.81'):
+        """Gets hardware inventory for the specific node.
+
+        :param uuid: Unique identifier of the node in UUID format.
+        :param api_version: Ironic API version to use.
+        :return: Inventory as a dictionary.
+
+        """
+        extra_headers, headers = self._get_headers(api_version)
+        resp, body = self._show_request(
+            'inventory', uuid, headers=headers, extra_headers=extra_headers,
+            uri=f'{self.uri_prefix}/nodes/{uuid}/inventory')
+        self.expected_success(http_client.OK, resp.status)
+        return body
+
+    @base.handle_errors
+    def get_shards(self, api_version='1.82'):
+        """Get all shards."""
+
+        extra_headers, headers = self._get_headers(api_version)
+        return self._list_request('shards', headers=headers,
+                                  extra_headers=extra_headers)
+
+    @base.handle_errors
+    def list_node_firmware(self, node_uuid):
+        """List firmware for a node.
+
+        :param node_uuid: The unique identifier of the node.
+        """
+        return self._list_request('/nodes/%s/firmware' % node_uuid)
